@@ -4,17 +4,17 @@
 modname = 'bootstrap'
 distname = 'cubicweb-bootstrap'
 
-numversion = (1, 6, 7)
+numversion = (1, 7, 0)
 version = '.'.join(str(num) for num in numversion)
 
 license = 'LGPL'
 author = 'LOGILAB S.A. (Paris, FRANCE)'
 author_email = 'contact@logilab.fr'
 description = ''
-web = 'https://www.cubicweb.org/project/%s' % distname
+web = 'https://forge.extranet.logilab.fr/cubicweb/cubes/%s' % distname
 
 __depends__ = {
-    'cubicweb': '>= 3.26.0',
+    'cubicweb': ">= 3.26.0, < 3.36.0",
     'six': '>= 1.12.0',
 }
 __recommends__ = {}
